@@ -11,10 +11,10 @@ export interface LayoutRow {
 
 export interface LayoutComponent {
   name: string,
-  is_empty: boolean,
-  is_pure_component: boolean,
   flow: string,
-  size: number
+  width: number,
+  height: number,
+  component_type: string
 }
 
 @Component({
@@ -46,12 +46,16 @@ export class SimpleLayout {
     for (let row of this.layout.rows) {
       let colId = 0;
       for (let component of row.columns) {
-        let id = that.layoutId(rowId, colId);
-
-        if (component.is_pure_component) {
-          this.createPureComponent(component, that, id);
-        } else {
-          this.createFlowComponent(component, that, id);
+        let id = SimpleLayout.layoutId(rowId, colId);
+        switch (component.component_type) {
+          case "native":
+            this.createPureComponent(component, that, id);
+            break;
+          case "flow":
+            this.createFlowComponent(component, that, id);
+            break;
+          default:
+            console.log("not supported type: " + component.component_type);
         }
         colId = colId + 1;
       }
@@ -61,7 +65,6 @@ export class SimpleLayout {
 
   private createPureComponent(component: LayoutComponent, that: this, id: string) {
     let element = document.createElement(component.flow);
-    // todo: refactor flow map to add by field;
     if (!that.flowMap[id]) {
       that.flowMap[id] = {};
     }
@@ -88,7 +91,7 @@ export class SimpleLayout {
     }
   }
 
-  private layoutId(rowId: number, colId: number) {
+  private static layoutId(rowId: number, colId: number) {
     return 'layout-' + rowId + '-' + colId;
   }
 
@@ -100,6 +103,19 @@ export class SimpleLayout {
     this.flowMap[id].id = id;
   }
 
+  private static countHeight(height: number) {
+    let styles = {};
+    let height_style = "100%";
+
+    if (height > 0 && height <= 12) {
+      height_style = height * (screen.height / 12) + "px"
+    }
+
+    styles['height'] = height_style;
+    styles['max-height'] = height_style;
+    return styles;
+  }
+
   render() {
     return (
       <Host ref={(el) => this.hostEl = el}>
@@ -108,8 +124,9 @@ export class SimpleLayout {
             {this.layout.rows.map((row, rowId) =>
               <ion-row>
                 {row.columns.map((col, colId) =>
-                  <ion-col class="quake-component" size={col.size.toString()}
-                           ref={(el) => (this.addElementToMap(el, this.layoutId(rowId, colId)))}>
+                  <ion-col class="quake-component" size={col.width.toString()}
+                           style={SimpleLayout.countHeight(col.height)}
+                           ref={(el) => (this.addElementToMap(el, SimpleLayout.layoutId(rowId, colId)))}>
                   </ion-col>
                 )}
               </ion-row>
