@@ -7,19 +7,19 @@ export type Props = {
   id: number,
   title: string,
   value: string,
-  entryType: string,
+  entrytype: string,
   onSave: (content: object) => any
 }
 
 function QuakeEditor(props: Props) {
   const [title, setTitle] = React.useState(props.title);
   const [value, setValue] = React.useState(props.value);
-  const [entryType] = React.useState(props.entryType);
-
+  const [entryType, setEntryType] = React.useState(props.entrytype);
+  const editor = React.createRef<Editor>();
 
   const pattern = /[a-zA-Z0-9_\u00A0-\u02AF\u0392-\u03c9\u0410-\u04F9]+|[\u4E00-\u9FFF\u3400-\u4dbf\uf900-\ufaff\u3040-\u309f\uac00-\ud7af]+/g;
   const wordCount = (data: string) => {
-    if(!data  || (!!data && data.length < 0)) {
+    if (!data || (!!data && data.length < 0)) {
       return 0;
     }
 
@@ -40,12 +40,14 @@ function QuakeEditor(props: Props) {
     setTitle(props.title);
   }, [props])
 
+  React.useEffect(() => {
+    setEntryType(props.entrytype);
+  }, [props])
 
   React.useEffect(() => {
     setValue(props.value);
   }, [props])
 
-
   const onSave = React.useCallback(() => {
     props.onSave({
       title: title,
@@ -53,42 +55,61 @@ function QuakeEditor(props: Props) {
     });
   }, [props, title, value])
 
+  function constructToc(headings: { title: string; level: number; id: string }[]) {
+    console.log(headings);
+  }
+
   const onChange = React.useCallback((getValue) => {
+    if (editor && editor.current) {
+      constructToc(editor.current.getHeadings());
+    }
+
     setValue(getValue())
-  }, [setValue]);
+  }, [setValue, editor]);
+
+  const changeTitle = React.useCallback((e) => {
+    setTitle(e.target.value)
+  }, [setTitle]);
 
   const saveEntry = () => {
     onSave();
   }
 
-  const uploadFile = async (_file: File, _options: any) => {
-    return {} as any;
-  }
-
+  // custom editor: https://github.com/outline/outline/blob/main/app/scenes/Document/components/Editor.tsx
   // https://github.com/outline/outline/blob/main/app/components/Editor.tsx
-  // https://github.com/outline/outline/blob/main/app/utils/uploadFile.ts
-  // https://github.com/SergioBenitez/Rocket/blob/master/examples/pastebin/src/main.rs
   const onUploadImage = React.useCallback(
     async (file: File) => {
-      const result = await uploadFile(file, {
-        entry_type: entryType,
-        id: props.id,
+      const formData = new FormData();
+      // @ts-expect-error ts-migrate(2339) FIXME: Property 'blob' does not exist on type 'File | Blo... Remove this comment to see the full error message
+      if (file.blob) {
+        // @ts-expect-error ts-migrate(2339) FIXME: Property 'file' does not exist on type 'File | Blo... Remove this comment to see the full error message
+        formData.append("file", file.file);
+      } else {
+        formData.append("file", file);
+      }
+      formData.append("name", file.name);
+
+      const uploadResponse = await fetch(`/processor/${entryType}/upload`, {
+        method: "post",
+        body: formData,
       });
-      return result.url;
+
+      return uploadResponse.text();
     },
-    [entryType, props]
+    [entryType]
   );
 
   return (
     <div>
       <StyledTitle>
         <StyleLabel># {props.id}</StyleLabel>
-        <StyleInput type="text" value={title} onChange={(e) => { setTitle(e.target.value)}}/>
+        <StyleInput type="text" value={title} onChange={changeTitle}/>
         <StyleButton onClick={saveEntry}>Save</StyleButton>
         <StyleCount>words：{wordCount(value)}</StyleCount>
       </StyledTitle>
       <StyledEditor
         autoFocus={true}
+        ref={editor}
         defaultValue={props.value}
         onChange={onChange}
         onSave={onSave}
