@@ -8,7 +8,7 @@ pub mod helper;
 pub mod quake_action;
 
 pub fn action(expr: QuakeActionNode, conf: QuakeConfig) -> Result<(), Box<dyn Error>> {
-    match expr.object.as_str() {
+    match expr.entry.as_str() {
         "quake" => quake_action::quake_action(expr.action, &conf),
         _ => entry_action::entry_action(&expr, conf),
     }
