@@ -6,20 +6,23 @@ use tracing::info;
 use quake_core::entry::entry_file::EntryFile;
 use quake_core::entry::EntryDefine;
 
-use crate::helper::exec_wrapper::exec_runner;
 use crate::helper::search_config::define_to_settings;
 
-pub fn feed_documents(server: &str, index_name: &str) -> Result<(), Box<dyn Error>> {
+pub fn feed_documents(
+    server: &str,
+    index_name: &str,
+    content: &[EntryFile],
+) -> Result<(), Box<dyn Error>> {
     let url = format!("{:}/indexes/{:}/documents", server, index_name);
-    let cmd_line = format!(
-        "curl -i -X POST '{:}' \
-  --header 'content-type: application/json' \
-  --data-binary @dump.json",
-        url
-    );
 
-    info!("{:?}", cmd_line);
-    exec_runner::cmd_runner(cmd_line)?;
+    info!("try feed to {:?} with {:?} len", url, content.len());
+    task::block_on(async {
+        let client = reqwest::Client::new();
+        let req = client.post(url).json(content).send();
+        let response = req.await.unwrap().text().await.unwrap();
+
+        info!("{:?}", response);
+    });
 
     Ok(())
 }
