@@ -3,13 +3,15 @@ use std::path::PathBuf;
 
 use serde_derive::{Deserialize, Serialize};
 
+use quake_core::entry::entry_paths::EntryPaths;
 use quake_core::entry::{EntryDefine, EntryDefines};
 
 pub fn create_suggest(workspace: &str) -> ActionSuggest {
     let mut suggest = ActionSuggest::default();
-    let path = PathBuf::from(workspace).join("entries-define.yaml");
+    let define_path = EntryPaths::entries_define();
+    let path = PathBuf::from(workspace).join(define_path);
 
-    let entries_str = fs::read_to_string(path).expect("cannot read entries-define.yaml");
+    let entries_str = fs::read_to_string(path).expect(&*format!("cannot read {:}", define_path));
     let entries: EntryDefines = serde_yaml::from_str(&*entries_str).unwrap();
     suggest.entries = entries.entries;
 
@@ -17,6 +19,7 @@ pub fn create_suggest(workspace: &str) -> ActionSuggest {
     for action in actions {
         suggest.actions.push(action.to_string());
     }
+
     suggest
 }
 
